@@ -1,14 +1,17 @@
-# $File: //member/autrijus/ExtUtils-AutoInstall/AutoInstall.pm $ 
-# $Revision: #39 $ $Change: 4805 $ $DateTime: 2003/03/19 13:41:43 $
+#line 1 "inc/ExtUtils/AutoInstall.pm - /usr/local/lib/perl5/site_perl/5.8.0/ExtUtils/AutoInstall.pm"
+# $File: //member/autrijus/ExtUtils-AutoInstall/lib/ExtUtils/AutoInstall.pm $ 
+# $Revision: #6 $ $Change: 8105 $ $DateTime: 2003/09/13 20:57:40 $
 
 package ExtUtils::AutoInstall;
-$ExtUtils::AutoInstall::VERSION = '0.48';
+$ExtUtils::AutoInstall::VERSION = '0.54';
 
 use strict;
 
 use Cwd;
 use ExtUtils::MakeMaker ();
 
+#line 264
+
 # special map on pre-defined feature sets
 my %FeatureMap = (
     ''	    => 'Core Features', # XXX: deprecated
@@ -41,7 +44,7 @@ sub _init {
 	    $Config = [ split(',', $1) ];
 	}
 	elsif ($arg =~ /^--installdeps=(.*)$/) {
-	    __PACKAGE__->install($Config, split(',', $1));
+	    __PACKAGE__->install($Config, @Missing = split(/,/, $1));
 	    exit 0;
 	}
 	elsif ($arg =~ /^--default(?:deps)?$/) {
@@ -139,7 +142,7 @@ sub import {
 		$DisabledTests{$_} = 1 for map { glob($_) } @skiptests;
 	    }
 	    else {
-		print "failed! (need".($arg ? "s $arg" : 'ed').")\n";
+		print "failed!" . ($arg ? " (needs $arg)" : '') . "\n";
 		push @required, $mod => $arg;
 	    }
 	}
@@ -235,7 +238,7 @@ sub install {
     my %args = @config;
     my %failed;
     local *FAILED;
-    if ($args{do_once} and open(FAILED, '.autoinstall.failed')) {
+    if ($args{do_once} and open(FAILED, '.#autoinstall.failed')) {
 	while (<FAILED>) { chomp; $failed{$_}++ }
 	close FAILED;
 
@@ -260,7 +263,7 @@ sub install {
 	if (defined(_version_check(_load($pkg), $ver))) {
 	    push @installed, $pkg;
 	}
-	elsif ($args{do_once} and open(FAILED, '>> .autoinstall.failed')) {
+	elsif ($args{do_once} and open(FAILED, '>> .#autoinstall.failed')) {
 	    print FAILED "$pkg\n";
 	}
     }
@@ -345,6 +348,8 @@ sub _install_cpan {
     my $installed = 0;
     my %args;
 
+    require CPAN; CPAN::Config->load;
+
     return unless _can_write(MM->catfile($CPAN::Config->{cpan_home}, 'sources'));
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
@@ -362,8 +367,6 @@ sub _install_cpan {
 	$CPAN::Config->{$opt} = $arg;
     }
 
-    require CPAN; CPAN::Config->load;
-
     while (my ($pkg, $ver) = splice(@modules, 0, 2)) {
 	MY::preinstall($pkg, $ver) or next if defined &MY::preinstall;
 
@@ -468,13 +471,36 @@ sub _can_write {
     my $path = shift;
     mkdir ($path, 0755) unless -e $path;
 
-    return (
-	-w $path or _prompt(qq(
+    require Config;
+    return 1 if -w $path and -w $Config::Config{sitelib};
+
+    print << ".";
 *** You are not allowed to write to the directory '$path';
     the installation may fail due to insufficient permissions.
+.
+
+    if (eval '$>' and lc(`sudo -V`) =~ /version/ and _prompt(qq(
+==> Should we try to re-execute the autoinstall process with 'sudo'?), 'y'
+    ) =~ /^[Yy]/) {
+	# try to bootstrap ourselves from sudo
+	print << ".";
+*** Trying to re-execute the autoinstall process with 'sudo'...
+.
+        my $missing = join(',', @Missing);
+        my $config  = join(',',
+	    UNIVERSAL::isa($Config, 'HASH') ? %{$Config} : @{$Config}
+        ) if $Config;
+
+	return unless system('sudo', $^X, $0, "--config=$config", "--installdeps=$missing");
+
+	print << ".";
+*** The 'sudo' command exited with error!  Resuming...
+.
+    }
+
+    return _prompt(qq(
 ==> Should we try to install the required module(s) anyway?), 'n'
-	) =~ /^[Yy]/
-    );
+    ) =~ /^[Yy]/
 }
 
 # load a module and return the version it reports
@@ -545,7 +571,7 @@ sub _make_args {
     ) if $Config;
 
     $PostambleActions = (
-	$missing ? "\$(PERLRUN) $0 --config=$config --installdeps=$missing"
+	$missing ? "\$(PERL) $0 --config=$config --installdeps=$missing"
 		 : "\@\$(NOOP)"
     );
 
@@ -603,3 +629,4 @@ installdeps ::
 
 __END__
 
+#line 910
